==> org-lsst-ccs-subsystem-shutter-main-4.2-sources.jar: org/lsst/ccs/subsystem/shutter/statemachine/Traveling.java <==
package org.lsst.ccs.subsystem.shutter.statemachine;

import org.lsst.ccs.subsystem.shutter.common.PhysicalState;
import java.util.logging.Logger;
import org.lsst.ccs.subsystem.shutter.plc.MotionDonePLC;
import static org.lsst.ccs.subsystem.shutter.statemachine.Logging.logEntry;
import static org.lsst.ccs.subsystem.shutter.statemachine.Logging.logEvent;
import static org.lsst.ccs.subsystem.shutter.statemachine.PromptReply.ACCEPTED;

/**
 * The state in which one blade set is retracting while the other is extending,
 * forming a traveling slit. Thread-safe.
 * @author tether
 */
class Traveling extends SimpleState<Prod> {
    private static final Logger LOG = Logger.getLogger(Traveling.class.getName());

    /**
     * Saves the context for this state.
     * @param context The context.
     * @throws NullPointerException if the context is null.
     */
    public Traveling(final Prod context) {
        super(context);
    }

    @Override
    public Logger getLogger() {
        return LOG;
    }

    @Override
    public void entry() {
        logEntry(this);
        getContext().getActions().setPhysicalState(PhysicalState.TRAVELING);
    }

    /**
     * {@inheritDoc} Publishes the motion profile on the status bus.
     * @return {@link PromptReply#ACCEPTED}
     */
    @Override
    public EventReply motionDone(final MotionDonePLC profileData) {
        logEvent(this);
        final Prod ctx = getContext();
        ctx.makeTransition(ctx.getClosingState(),
                () -> ctx.getActions().sendProfile(profileData));
        return ACCEPTED;
    }
}

==> org-lsst-ccs-subsystem-shutter-main-4.4-sources.jar: org/lsst/ccs/subsystem/shutter/statemachine/Traveling.java <==
package org.lsst.ccs.subsystem.shutter.statemachine;

import org.lsst.ccs.subsystem.shutter.common.PhysicalState;
import java.util.logging.Logger;
import org.lsst.ccs.subsystem.shutter.common.SoftwareState;
import org.lsst.ccs.subsystem.shutter.plc.MotionDonePLC;
import static org.lsst.ccs.subsystem.shutter.statemachine.Logging.logEntry;
import static org.lsst.ccs.subsystem.shutter.statemachine.Logging.logEvent;
import static org.lsst.ccs.subsystem.shutter.statemachine.PromptReply.ACCEPTED;

/**
 * The state in which one blade set is retracting while the other is extending,
 * forming a traveling slit. Thread-safe.
 * @author tether
 */
class Traveling extends SimpleState<Prod> {
    private static final Logger LOG = Logger.getLogger(Traveling.class.getName());

    /**
     * Saves the context for this state.
     * @param context The context.
     * @throws NullPointerException if the context is null.
     */
    public Traveling(final Prod context) {
        super(context);
    }

    @Override
    public Logger getLogger() {
        return LOG;
    }

    @Override
    public void entry() {
        logEntry(this);
        getContext().getActions().setSoftwareState(SoftwareState.TRAVELING);
        getContext().getActions().setPhysicalState(PhysicalState.TRAVELING);
    }

    /**
     * {@inheritDoc} Publishes the motion profile on the status bus.
     * @return {@link PromptReply#ACCEPTED}
     */
    @Override
    public EventReply motionDone(final MotionDonePLC profileData) {
        logEvent(this);
        final Prod ctx = getContext();
        ctx.makeTransition(ctx.getClosingState(),
                () -> ctx.getActions().sendProfile(profileData));
        return ACCEPTED;
    }
}
